@@ -71,10 +71,12 @@ impl Script {
         }
 
         let opcode_str = match FromPrimitive::from_u8(byte) {
-            // Some(v @ OpCodes::OP_0) => match extended {
-            //     true => v.to_string(),
-            //     false => 0.to_string(),
-            // },
+            Some(v @ OpCodes::OP_0) => match extended {
+                true => v.to_string(),
+                false => {
+                    0.to_string()
+                },
+            },
             Some(v @ OpCodes::OP_PUSHDATA1) => Script::format_pushdata_string(cursor, v, extended)?,
             Some(v @ OpCodes::OP_PUSHDATA2) => Script::format_pushdata_string(cursor, v, extended)?,
             Some(v @ OpCodes::OP_PUSHDATA4) => Script::format_pushdata_string(cursor, v, extended)?,
@@ -130,21 +132,30 @@ impl Script {
         }
     }
 
+    /**
+     * OpCodes such as OP_PUSH or the numerical OpCodes (OP_1-OP_16)
+     */
     fn get_special_opcode(
         byte: u8,
         extended: bool,
         cursor: &mut Cursor<Vec<u8>>,
     ) -> Result<Option<String>, ScriptErrors> {
-        Ok(match byte {
+        let code = match byte {
             size @ 0x01..=0x4b => {
                 let pushdata = Script::get_pushdata(cursor, size as usize)?;
                 match extended {
                     true => Some(format!("OP_PUSH {} {}", size, pushdata)),
                     false => Some(pushdata),
                 }
-            }
+            },
+
+            v @ 82..=96 => match OpCodes::from_u8(v) {
+                Some(num_opcode) => Some(num_opcode.to_string()),
+                None => None
+            },
             _ => None,
-        })
+        };
+        Ok(code)
     }
 
     fn format_pushdata_string(
